<?php

namespace App\Http\Controllers\Admin;

use App\Http\Traits\MessageStatusTrait;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\BusinessOrderType;
use App\Models\BusinessCategory;
use App\Models\OrderType;
use App\Models\Business;
use App\Models\Category;
use App\Models\Country;
use App\Models\Owner;
use App\Models\State;
use App\Models\City;
use Validator;
use Auth;
use Hash;
use File;

class BusinessController extends Controller
{
    use MessageStatusTrait;

    # Bind location
    protected $view = 'admin.business.';
    protected $type = 'Owner ';


    # Bind owner
    protected $city;
    protected $owner;
    protected $state;
    protected $country;
    protected $category;
    protected $business;
    protected $orderType;
    protected $businessCategory;
    protected $businessOrderType;
  
    /**
     * default constructor
     * @param
     * @return
     */
    function __construct(
                          City       $city,
                          Owner      $owner,
                          State      $state,
                          Country    $country,
                          Category   $category,
                          Business  $business,
                          BusinessCategory  $businessCategory,
                          BusinessOrderType  $businessOrderType,
                          OrderType  $orderType
                        )
                        {
                            $this->city      = $city;
                            $this->state     = $state;
                            $this->owner     = $owner;
                            $this->country   = $country;
                            $this->category  = $category;
                            $this->business = $business;
                            $this->businessCategory = $businessCategory;
                            $this->businessOrderType = $businessOrderType;
                            $this->orderType = $orderType;
                            $this->page      = config('paginate.pagination');
                        }



   
    #business page
    public function index(Request $request){
        $query = $this->business;
      
        $business_list = $query->orderBy('id','desc')->paginate($this->page);

        return view($this->view.'index')->with([
                                                 'business_list'  => $business_list ?? [],
                                               ]);
    }



     #owner add page
    public function create(Request $request){
          $owner_list = $this->owner->where('status',1)->orderBy('id','desc')->get(); 
         
          return view($this->view.'add')->with([
                                                 'owner_list'     => $owner_list,
                                               ]);
    }



    /**
      * add category
      * @param Illuminate\Http\Request; 
      * @return Illuminate\Http\Response;
      */
     public function store(Request $request)
     {
      $data = [
                'owner_id'         => 'required',
                'name'             => 'required',
                'mobile'           => 'required',
                'email'            => 'required',
                'address'          => 'required',
                'latitude'         => 'required',
                'longitude'        => 'required',
                'description'      => 'required',
             ];

            # validation check
            $validator = Validator::make($request->all() , $data);
            if($validator->fails())
             {
                return response()->json([
                                          'responseCode'    =>  $this->errorStatus, 
                                          'responseMessage' => 'Required field is missing.'
                                        ]);
             }

            try { 

                  $ownerData = $this->owner->where('id', $request->owner_id)->first();

                  $client = new \GuzzleHttp\Client();

                  $URI = 'http://localhost/metapos_new_dev/backoffice/public/api/saas/store-market';
                  $params['headers'] = ['Content-Type' => 'application/json'];
                  $params['query'] = array(
                                           'owner_id'     => $ownerData->reference_owner_id,
                                           'name'         => $request->name ?? null,
                                           'desc'         => $request->description ?? null,
                                           'phone'        => $request->mobile ?? null,
                                           'mobilephone'  => $request->alt_mobile ?? null,
                                           'address'      => $request->address ?? null,
                                           'lat'          => $request->latitude ?? null,
                                           'lng'          => $request->longitude ?? null,
                                          );

                  $response = $client->post($URI, $params);
                  $return_data = json_decode($response->getBody()->getContents());
                    if($return_data->code == '401'){
                      return response()->json([
                                                  'responseCode'    =>  $this->errorStatus, 
                                                  'responseMessage' =>  $return_data->message
                                              ]);
                    }

                   #check the requested email already exist or not
                    $checkEmail = $this->business
                                       ->where('email', $request->email)
                                       ->first();

                   
                   if($checkEmail)
                    {   
                      return response()->json([
                                                'responseCode'    =>  $this->errorStatus, 
                                                'responseMessage' =>'Sorry, this email already exist.'
                                              ]);  
                    }

                   
                 #upload image
                // if ($request->hasfile('image'))
                // {
                //     $file = $request->file('image');
                //     $extension = $file->getClientOriginalExtension(); // getting image extension
                //     $filename =((string)(microtime(true)*10000)).'.'.$extension;
                //     $file->move(public_path('images/business/'), $filename);
                //     $Image='images/business/'.$filename;
                // }else{
                //     $Image = null;
                // }
                
                # request param
                $arrayData = [
                               'owner_id'            => $request->owner_id ?? null,
                               'reference_market_id' => $return_data->market_id,
                               'name'                => $request->name ?? null,
                               'email'               => $request->email ?? null,
                               'mobile'              => $request->mobile ?? null,
                               'alt_mobile'          => $request->alt_mobile ?? null,
                               'address'             => $request->address ?? null,
                               'latitude'            => $request->latitude ?? null,
                               'longitude'           => $request->longitude ?? null,
                               'website_url'         => $request->website_url ?? null,
                               'description'         => $request->description ?? null,
                               'status'              => 1,
                               //'logo'                => $Image ?? null,
                             ];     

                     
                #store
                $business_store = $this->business->create($arrayData); 

                return response()->json([
                                          'responseCode'    =>$this->successStatus, 
                                          'responseMessage' => 'Business added successfully.'
                                        ]);                      

            } catch (Exception $e) {
                return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => 'Something went wrong.'
                                        ]);  
            }
     }


    /**
     * edit page
     * @param Illuminate\Http\Request;
     * @return Illuminate\Http\Response;
     */
    public function update($id)
    {  
         # Fetch business by id
         $business = $this->business
                           ->where('id', $id)
                           ->first();

          $owner_list = $this->owner->where('status',1)->orderBy('id','desc')->get();

        # code...
        return view($this->view . 'edit')->with([
                                                  'business'       => $business,
                                                  'owner_list'     => $owner_list,
                                               ]);
    }



    /**
      * edit category
      * @param Illuminate\Http\Request; 
      * @return Illuminate\Http\Response;
      */
     public function edit(Request $request)
     {
          $data = [
                'business_id'      => 'required',
                'owner_id'         => 'required',
                'name'             => 'required',
                'mobile'           => 'required',
                'email'            => 'required',
                'address'          => 'required',
                'latitude'         => 'required',
                'longitude'        => 'required',
                'description'      => 'required',
             ];

            # validation check
            $validator = Validator::make($request->all() , $data);
            if($validator->fails())
             {
                return response()->json([
                                          'responseCode'    =>  $this->errorStatus, 
                                          'responseMessage' => 'Required field is missing.'
                                        ]);
             }

            try {

                  $query = $this->business
                             ->where('id', $request->business_id)
                             ->first();

                  $ownerData = $this->owner->where('id', $request->owner_id)->first();

                  $client = new \GuzzleHttp\Client();

                  $URI = 'http://localhost/metapos_new_dev/backoffice/public/api/saas/update-market';
                  $params['headers'] = ['Content-Type' => 'application/json'];
                  $params['query'] = array(
                                           'id'           => $query->reference_market_id,
                                           'owner_id'     => $ownerData->reference_owner_id ?? null,
                                           'name'         => $request->name ?? null,
                                           'desc'         => $request->description ?? null,
                                           'phone'        => $request->mobile ?? null,
                                           'mobilephone'  => $request->alt_mobile ?? null,
                                           'address'      => $request->address ?? null,
                                           'lat'          => $request->latitude ?? null,
                                           'lng'          => $request->longitude ?? null,
                                          );

                  $response = $client->post($URI, $params);
                  $return_data = json_decode($response->getBody()->getContents());
                    if($return_data->code == '401'){
                      return response()->json([
                                                  'responseCode'    =>  $this->errorStatus, 
                                                  'responseMessage' =>  $return_data->message
                                              ]);
                    }


                     #check the requested email already exist or not
                    $checkEmail = $this->business
                                       ->where('email', $request->email)
                                       ->where('id','!=' ,$request->business_id)
                                       ->first();

                   
                   if($checkEmail)
                    {   
                      return response()->json([
                                                'responseCode'    =>  $this->errorStatus, 
                                                'responseMessage' =>'Sorry, this email already exist.'
                                              ]);  
                    }

                    
              
              
                              
                #upload image
                // if ($request->hasfile('image'))
                // {
                //     $file = $request->file('image');
                //     $extension = $file->getClientOriginalExtension(); // getting image extension
                //     $filename =((string)(microtime(true)*10000)).'.'.$extension;
                //     $file->move(public_path('images/business/'), $filename);
                //     $Image='images/business/'.$filename;
                // }else{
                //     $Image = $query->logo ?? null;
                // }
                
                # request param
                # request param
                $arrayData = [
                               'owner_id'            => $request->owner_id ?? null,
                               'name'                => $request->name ?? null,
                               'email'               => $request->email ?? null,
                               'mobile'              => $request->mobile ?? null,
                               'alt_mobile'          => $request->alt_mobile ?? null,
                               'address'             => $request->address ?? null,
                               'latitude'            => $request->latitude ?? null,
                               'longitude'           => $request->longitude ?? null,
                               'website_url'         => $request->website_url ?? null,
                               'description'         => $request->description ?? null,
                               'status'              => 1,
                               //'logo'                => $Image ?? null,
                             ];     

                     
                #update
                $update = $query->update($arrayData); 

                return response()->json([
                                          'responseCode'    =>$this->successStatus, 
                                          'responseMessage' => 'Business Updated Successfully.'
                                        ]);                      

            } catch (Exception $e) {
                return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => 'Something went wrong.'
                                        ]);  
            }
     }




   
}
