<?php

namespace App\Http\Controllers\Admin;

use App\Http\Traits\MessageStatusTrait;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\User;
use Validator;
use Auth;
use Hash;
use File;

class LoginController extends Controller
{
    use MessageStatusTrait;

    # Bind location
    protected $view = 'admin.';

    # Bind banner
    protected $user;
  
    /**
     * default constructor
     * @param
     * @return
     */
     function __construct(User $user)
    {
        $this->user = $user;
    }



    #Admin login page
    public function index(Request $request){

        return view($this->view.'login');
    }

    #Admin login
    public function login(Request $request)
    { 
        #  Validate field Data
        $validator = Validator::make($request->all(), [ 
            'email'          => 'required',
            'password'       => 'required',
        ]);
        if ($validator->fails()) { 
            return response()->json(['error'=>$validator->errors()], $this->failedStatus);            
        }
        #
        $credentials = $request->only('email',  'password');
        
        try{ 
                if (!Auth::attempt($credentials)) 
                {
                        return response()->json([
                                                  'message' => 'Given credential are not matched',
                                                  'code'    =>  (string)$this->failedStatus,
                                                ]);
                }else{
                       
                        $user = Auth::user();
                         if($user)
                         {

                            if ($user->status == 0) 
                                {
                                        return response()->json([
                                                                  'message' => 'Your profile is inactive',
                                                                  'code'    =>  (string)$this->failedStatus,
                                                                ]);
                                }
                                 return response()->json([
                                                           'message' => 'You have successfully logged in',
                                                           'code'    =>  (string)$this->successStatus,
                                                        ]);
                         }else{
                                 Auth::logout();
                                 return response()->json([
                                                           'message' => 'Given credential are not matched',
                                                           'code'    =>  (string)$this->failedStatus,
                                                        ]);
                         }
                }
            
            }catch (\Exception $e) {
                  # return response
                  return response()->json([
                                            'code'    =>(string)$this->failedStatus, 
                                            'message' => 'Something Went Wrong'
                                          ]);     
            }
       }




    /**
     * edit page
     * @param Illuminate\Http\Request;
     * @return Illuminate\Http\Response;
     */
    public function profile()
    {
        # Fetch user by id
         $user = $this->user->where('id', Auth::user()->id)->first();
        # code...
        return view($this->view . 'profile')->with(['user' => $user]);
    }



    /**
      * edit profile
      * @param Illuminate\Http\Request; 
      * @return Illuminate\Http\Response;
      */
     public function edit_profile(Request $request)
     {
     
      $data = ['first_name' => 'required'];

            # validation check
            $validator = Validator::make($request->all() , $data);
            if($validator->fails())
             {
                return response()->json([
                                          'responseCode'    =>  $this->errorStatus, 
                                          'responseMessage' => 'Required field is missing.'
                                        ]);
             }

            try {
              
               $query = $this->user
                             ->where('id', Auth::user()->id)
                             ->first();
               
                
                 #upload profile_image
                if ($request->hasfile('profile_image'))
                {
                    $file = $request->file('profile_image');
                    $extension = $file->getClientOriginalExtension(); // getting image extension
                    $filename =((string)(microtime(true)*10000)).'.'.$extension;
                    File::delete(public_path($query->profile_image));
                    $file->move(public_path('images/profile/'), $filename);
                    $profile_image='images/profile/'.$filename;
                }else{
                    $profile_image = $query->profile_image;
                }                


                # request param
                $arrayData = [
                               'first_name'    => $request->first_name ?? null, 
                               'last_name'     => $request->last_name ?? null,
                               'profile_image' => $profile_image,
                             ];     

                #update
                $update = $query->update($arrayData);  
                
                return response()->json([
                                          'responseCode'    =>$this->successStatus, 
                                          'responseMessage' => 'Profile updated successfully.'
                                        ]);                      

            } catch (Exception $e) {
               // dd($e);
                return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => 'Something went wrong.'
                                        ]);  
            }
     }



 /**
      * change_password
      * @param Illuminate\Http\Request; 
      * @return Illuminate\Http\Response;
      */
     public function change_password(Request $request)
     {
     
      $data = ['confirm_password' => 'required','new_password' => 'required','confirm_password' => 'required'];

            # validation check
            $validator = Validator::make($request->all() , $data);
            if($validator->fails())
             {
                return response()->json([
                                          'responseCode'    =>  $this->errorStatus, 
                                          'responseMessage' => 'Required field is missing.'
                                        ]);
             }

            try {
              
               $query = $this->user
                             ->where('id', Auth::user()->id)
                             ->first();
               
                
                if(Hash::check($request->get('current_password'), $query->password)){
                     
                     if($request->get('new_password') != $request->get('confirm_password'))
                     {
                         return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => 'New password and confirm password not matched.'
                                        ]);
                     }

                    # request param
                    $arrayData = [
                                   'password'    => Hash::make($request->new_password) ?? null,
                                 ];     

                    #update
                    $update = $query->update($arrayData);  
                    
                    return response()->json([
                                              'responseCode'    =>$this->successStatus, 
                                              'responseMessage' => 'password changed successfully.'
                                            ]);  
                }else{
                     return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => 'Current password not correct.'
                                        ]);   
                }               


                                      

            } catch (Exception $e) {
               // dd($e);
                return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => 'Something went wrong.'
                                        ]);  
            }
     }

    

    #Admin logout
    public function logout(){
       Auth::logout();
       return redirect()->route('admin-login');
    }
}
