<?php

namespace App\Http\Controllers\Admin;

use App\Http\Traits\MessageStatusTrait;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Module;
use Validator;
use Auth;
use Hash;
use File;

class ModuleController extends Controller
{
    use MessageStatusTrait;

    # Bind location
    protected $view = 'admin.module.';
    protected $type = 'Module ';


    # Bind module
    protected $module;
  
    /**
     * default constructor
     * @param
     * @return
     */
    function __construct(
                          Module $module
                        )
                        {
                            $this->module   = $module;
                            $this->page = config('paginate.pagination');
                        }



   
    #module page
    public function index(Request $request){
        $query = $this->module;
      
        $module_list = $query->orderBy('id','desc')->paginate($this->page);
        return view($this->view.'index')->with([
                                                 'module_list'  => $module_list ?? [],
                                               ]);
    }



     #module add page
    public function create(Request $request){
          return view($this->view.'add');
    }



    /**
      * add module
      * @param Illuminate\Http\Request; 
      * @return Illuminate\Http\Response;
      */
     public function store(Request $request)
     {
      $data = [
                'name'           => 'required',
             ];

            # validation check
            $validator = Validator::make($request->all() , $data);
            if($validator->fails())
             {
                return response()->json([
                                          'responseCode'    =>  $this->errorStatus, 
                                          'responseMessage' => 'Required field is missing.'
                                        ]);
             }

            try { 
                
                # request param
                $arrayData = [
                               'name'            => $request->name ?? null,
                               'status'          => 1
                             ];     

                #store
                $storemodule = $this->module->create($arrayData); 

                               
                return response()->json([
                                          'responseCode'    =>$this->successStatus, 
                                          'responseMessage' => 'Module added successfully.'
                                        ]);                      

            } catch (Exception $e) {
                return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => 'Something went wrong.'
                                        ]);  
            }
     }


    /**
     * edit page
     * @param Illuminate\Http\Request;
     * @return Illuminate\Http\Response;
     */
    public function update($id)
    {  
        # Fetch module by id
         $module = $this->module
                           ->where('id', $id)
                           ->first();
        # code...
        return view($this->view . 'edit')->with(['module' => $module]);
    }



    /**
      * edit module
      * @param Illuminate\Http\Request; 
      * @return Illuminate\Http\Response;
      */
     public function edit(Request $request)
     {
        $data = [
                'name'           => 'required',
             ];

            # validation check
            $validator = Validator::make($request->all() , $data);
            if($validator->fails())
             {
                return response()->json([
                                          'responseCode'    =>  $this->errorStatus, 
                                          'responseMessage' => 'Required field is missing.'
                                        ]);
             }
             
            try {
              
               $query = $this->module
                             ->where('id', $request->id)
                             ->first();
                              
               # request param
                $arrayData = [
                               'name'            => $request->name ?? null,
                             ];   

                #update
                $updatemodule = $query->update($arrayData); 

                return response()->json([
                                          'responseCode'    =>$this->successStatus, 
                                          'responseMessage' => 'Module Updated Successfully.'
                                        ]);                      

            } catch (Exception $e) {
                return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => 'Something went wrong.'
                                        ]);  
            }
     }


   /**
     * delete module
     * @param $id
     * @return \Illuminate\Http\Response
     */
    public function delete($id)
    {
        $query = $this->module;

        # delete module by id
        $query->where('id', $id)->delete();

        # return success
        return [$this->successKey => $this->successStatus, $this->messageKey => $this->deleteMessage($this->type) ];
    }


   
}
