<?php

namespace App\Http\Controllers\Admin;

use App\Http\Traits\MessageStatusTrait;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Owner;
use App\Models\Country;
use App\Models\State;
use App\Models\City;
use Validator;
use Auth;
use Hash;
use File;

class OwnerController extends Controller
{
    use MessageStatusTrait;

    # Bind location
    protected $view = 'admin.owner.';
    protected $type = 'Owner ';


    # Bind owner
    protected $owner;
    protected $country;
    protected $state;
    protected $city;
  
    /**
     * default constructor
     * @param
     * @return
     */
    function __construct(
                          Owner   $owner,
                          Country $country,
                          State   $state,
                          City    $city
                        )
                        {
                            $this->owner     = $owner;
                            $this->country   = $country;
                            $this->state     = $state;
                            $this->city      = $city;
                            $this->page = config('paginate.pagination');
                        }



   
    #owner page
    public function index(Request $request){
        $query = $this->owner;
      
        $owner_list = $query->orderBy('id','desc')->paginate($this->page);

        return view($this->view.'index')->with([
                                                 'owner_list'  => $owner_list ?? [],
                                               ]);
    }



     #owner add page
    public function create(Request $request){
          $country_list = $this->country->get(); 

          return view($this->view.'add')->with(['country_list' => $country_list]);
    }



    /**
      * add category
      * @param Illuminate\Http\Request; 
      * @return Illuminate\Http\Response;
      */
     public function store(Request $request)
     {
      $data = [
                'name'             => 'required',
                'email'            => 'required',
                'mobile'           => 'required',
                'country_id'       => 'required',
                'state_id'         => 'required',
                'city_id'          => 'required',
                'address'          => 'required',
                'type'             => 'required',
             ];

            # validation check
            $validator = Validator::make($request->all() , $data);
            if($validator->fails())
             {
                return response()->json([
                                          'responseCode'    =>  $this->errorStatus, 
                                          'responseMessage' => 'Required field is missing.'
                                        ]);
             }

            try { 



                $client = new \GuzzleHttp\Client();

                $URI = 'http://localhost/metapos_new_dev/backoffice/public/api/saas/store-owner';
                $params['headers'] = ['Content-Type' => 'application/json'];
                $params['query'] = array(
                                         'name'       => $request->name ?? null,
                                         'email'      => $request->email ?? null,
                                         'phone'      => $request->mobile ?? null,
                                         'country_id' => $request->country_id ?? null,
                                         'state_id'   => $request->state_id ?? null,
                                         'city_id'    => $request->city_id ?? null,
                                         'address'    => $request->address ?? null,
                                         'password'   => '12345',
                                        );

                $response = $client->post($URI, $params);
                $return_data = json_decode($response->getBody()->getContents());
                  if($return_data->code == '401'){
                    return response()->json([
                                                'responseCode'    =>  $this->errorStatus, 
                                                'responseMessage' =>  $return_data->message
                                            ]);
                  }

                   #check the requested owner already exist or not
                    $checkEmail = $this->owner
                                       ->where('email', $request->email)
                                       ->first();

                   
                   if($checkEmail)
                    {   
                      return response()->json([
                                                'responseCode'    =>  $this->errorStatus, 
                                                'responseMessage' =>'Sorry, this email11 already exist.'
                                              ]);  
                    }

                 #upload image
                if ($request->hasfile('image'))
                {
                    $file = $request->file('image');
                    $extension = $file->getClientOriginalExtension(); // getting image extension
                    $filename =((string)(microtime(true)*10000)).'.'.$extension;
                    $file->move(public_path('images/owner/'), $filename);
                    $Image='images/owner/'.$filename;
                }else{
                    $Image = null;
                }
                
                # request param
                $arrayData = [
                               'name'            => $request->name ?? null,
                               'email'           => $request->email ?? null,
                               'mobile'          => $request->mobile ?? null,
                               'country_id'      => $request->country_id ?? null,
                               'state_id'        => $request->state_id ?? null,
                               'city_id'         => $request->city_id ?? null,
                               'address'         => $request->address ?? null,
                               'type'            => $request->type ?? null,
                               'status'          => 1,
                               'profile_image'   => $Image ?? null,
                               'reference_owner_id' => $return_data->user_id,
                             ];     

                #store
                $store = $this->owner->create($arrayData); 

                               
                return response()->json([
                                          'responseCode'    =>$this->successStatus, 
                                          'responseMessage' => 'Owner added successfully.'
                                        ]);                      

            } catch (Exception $e) {
                return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => 'Something went wrong.'
                                        ]);  
            }
     }


    /**
     * edit page
     * @param Illuminate\Http\Request;
     * @return Illuminate\Http\Response;
     */
    public function update($id)
    {  
         # Fetch owner by id
         $owner = $this->owner
                       ->where('id', $id)
                       ->first();

          $country_list = $this->country->get(); 

          # fetch states 
          $states = $this->state
                         ->where('country_id',$owner->country_id)
                         ->select('country_id', 'id', 'name')
                         ->get(); 

          $cities  = $this->city
                          ->where('state_id',$owner->state_id)
                          ->select('id', 'name')
                          ->get();

       
        # code...
        return view($this->view . 'edit')->with([
                                                  'owner'        => $owner,
                                                  'country_list' => $country_list,
                                                  'states'       => $states,
                                                  'cities'       => $cities,
                                               ]);
    }



    /**
      * edit category
      * @param Illuminate\Http\Request; 
      * @return Illuminate\Http\Response;
      */
     public function edit(Request $request)
     {
           $data = [
                'name'             => 'required',
                'email'            => 'required',
                'mobile'           => 'required',
                'country_id'       => 'required',
                'state_id'         => 'required',
                'city_id'          => 'required',
                'address'          => 'required',
                'type'             => 'required',
             ];

            # validation check
            $validator = Validator::make($request->all() , $data);
            if($validator->fails())
             {
                return response()->json([
                                          'responseCode'    =>  $this->errorStatus, 
                                          'responseMessage' => 'Required field is missing.'
                                        ]);
             }

            try {
                    $query = $this->owner
                                  ->where('id', $request->id)
                                  ->first();


                    $client = new \GuzzleHttp\Client();

                    $URI = 'http://localhost/metapos_new_dev/backoffice/public/api/saas/update-owner';
                    $params['headers'] = ['Content-Type' => 'application/json'];
                    $params['query'] = array(
                                             'id'         => $query->reference_owner_id,
                                             'name'       => $request->name ?? null,
                                             'email'      => $request->email ?? null,
                                             'phone'      => $request->mobile ?? null,
                                             'country_id' => $request->country_id ?? null,
                                             'state_id'   => $request->state_id ?? null,
                                             'city_id'    => $request->city_id ?? null,
                                             'address'    => $request->address ?? null,
                                            );

                    $response = $client->post($URI, $params);
                    $return_data = json_decode($response->getBody()->getContents());
                      if($return_data->code == '401'){
                        return response()->json([
                                                    'responseCode'    =>  $this->errorStatus, 
                                                    'responseMessage' =>  $return_data->message
                                                ]);
                      }

                    #check the requested owner already exist or not
                    $checkEmail = $this->owner
                                       ->where('email', $request->email)
                                       ->where('id', '!=',$request->id)
                                       ->first();

                   
                   if($checkEmail)
                    {   
                      return response()->json([
                                                'responseCode'    =>  $this->errorStatus, 
                                                'responseMessage' =>'Sorry, this email already exist.'
                                              ]);  
                    }
              
                                             
                #upload image
                if ($request->hasfile('image'))
                {
                    $file = $request->file('image');
                    $extension = $file->getClientOriginalExtension(); // getting image extension
                    $filename =((string)(microtime(true)*10000)).'.'.$extension;
                    $file->move(public_path('images/owner/'), $filename);
                    $Image='images/owner/'.$filename;
                }else{
                    $Image = $query->profile_image ?? null;
                }
                
                # request param
                $arrayData = [
                               'name'            => $request->name ?? null,
                               'email'           => $request->email ?? null,
                               'mobile'          => $request->mobile ?? null,
                               'country_id'      => $request->country_id ?? null,
                               'state_id'        => $request->state_id ?? null,
                               'city_id'         => $request->city_id ?? null,
                               'address'         => $request->address ?? null,
                               'type'            => $request->type ?? null,
                               'profile_image'   => $Image ?? null,
                             ];     

                #update
                $update = $query->update($arrayData); 

                return response()->json([
                                          'responseCode'    =>$this->successStatus, 
                                          'responseMessage' => 'Owner Updated Successfully.'
                                        ]);                      

            } catch (Exception $e) {
                return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => $e
                                        ]);  
            }
     }





/**
  * json responce of state by country id by ajax for dependent dropdown respons
  * @param
  * @return \Illuminate\Http\Response in json
  */
  public function jsonState(Request $request)
  {
    # fetch state 
    $state = $this->state
                   ->where('country_id',$request->country_id)
                   ->select('id', 'name')
                   ->get();

    # return json responce
    return response()->json($state);
  } 


  /**
  * json responce of city by country id by ajax for dependent dropdown respons
  * @param
  * @return \Illuminate\Http\Response in json
  */
  public function jsonCity(Request $request)
  {
    # fetch city 
    $city = $this->city
                   ->where('state_id',$request->state_id)
                   ->select('id', 'name')
                   ->get();

    # return json responce
    return response()->json($city);
  } 

   
}
