<?php

namespace App\Http\Controllers\Admin;

use App\Http\Traits\MessageStatusTrait;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\PackageModule;
use App\Models\Module;
use App\Models\Business;
use App\Models\PackageAssignModule;
use Validator;
use Auth;
use Hash;
use File;

class PackageAssignModuleController extends Controller
{
    use MessageStatusTrait;

    # Bind location
    protected $view = 'admin.package-assign-module.';
    protected $type = 'Package Assign Module ';


    # Bind packageModule
    protected $packageModule;
    protected $module;
    protected $business;
    protected $packageAssignModule;
  
    /**
     * default constructor
     * @param
     * @return
     */
    function __construct(
                          Module        $module,
                          Business $business,
                          PackageAssignModule $packageAssignModule,
                          PackageModule $packageModule
                        )
                        {
                            $this->module          = $module;
                            $this->packageModule   = $packageModule;
                            $this->business         = $business;
                            $this->packageAssignModule   = $packageAssignModule;
                            $this->page = config('paginate.pagination');
                        }



   
    #packageAssignModule page
    public function index(Request $request){
        $query = $this->packageAssignModule;
      
        $packageAssignModule_list = $query->orderBy('id','desc')->paginate($this->page);
        return view($this->view.'index')->with([
                                                 'packageAssignModule_list'  => $packageAssignModule_list ?? [],
                                               ]);
    }



     #packageAssignModule add page
    public function create(Request $request){
          $business_list = $this->business->where('status',1)->get();
          $package_list = $this->packageModule->where('status',1)->get();
          return view($this->view.'add')->with(['business_list' => $business_list,'package_list' => $package_list]);
    }



    /**
      * add packageModule
      * @param Illuminate\Http\Request; 
      * @return Illuminate\Http\Response;
      */
     public function store(Request $request)
     {
      $data = [
                'business_id'           => 'required',
                'package_id'       => 'required',
                'start_date'      => 'required',
                'end_date'      => 'required',
             ];

            # validation check
            $validator = Validator::make($request->all() , $data);
            if($validator->fails())
             {
                return response()->json([
                                          'responseCode'    =>  $this->errorStatus, 
                                          'responseMessage' => 'Required field is missing.'
                                        ]);
             }

            try { 
                
                # request param
                $arrayData = [
                               'business_id'            => $request->business_id ?? null,
                               'package_id'        => $request->package_id ?? null,
                               'start_date'       => $request->start_date ?? null,
                               'end_date'       => $request->end_date ?? null,
                               'status'          => 1
                             ];     

                #store
                $storepackageModule = $this->packageAssignModule->create($arrayData); 

                               
                return response()->json([
                                          'responseCode'    =>$this->successStatus, 
                                          'responseMessage' => 'Package assign module added successfully.'
                                        ]);                      

            } catch (Exception $e) {
                return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => 'Something went wrong.'
                                        ]);  
            }
     }


    /**
     * edit page
     * @param Illuminate\Http\Request;
     * @return Illuminate\Http\Response;
     */
    public function update($id)
    {  
        # Fetch packageAssignModule by id
         $packageAssignModule = $this->packageAssignModule
                           ->where('id', $id)
                           ->first();
        $business_list = $this->business->where('status',1)->get();
          $package_list = $this->packageModule->where('status',1)->get();                  
        # code...
        return view($this->view . 'edit')->with(['packageAssignModule' => $packageAssignModule,'business_list' => $business_list,'package_list' => $package_list]);
    }



    /**
      * edit packageAssignModule
      * @param Illuminate\Http\Request; 
      * @return Illuminate\Http\Response;
      */
     public function edit(Request $request)
     {
        $data = [
                'business_id'           => 'required',
                'package_id'       => 'required',
                'start_date'      => 'required',
                'end_date'      => 'required',
             ];

            # validation check
            $validator = Validator::make($request->all() , $data);
            if($validator->fails())
             {
                return response()->json([
                                          'responseCode'    =>  $this->errorStatus, 
                                          'responseMessage' => 'Required field is missing.'
                                        ]);
             }
             
            try {
              
               $query = $this->packageAssignModule
                             ->where('id', $request->id)
                             ->first();
                              
                # request param
                $arrayData = [
                               'business_id'            => $request->business_id ?? null,
                               'package_id'        => $request->package_id ?? null,
                               'start_date'       => $request->start_date ?? null,
                               'end_date'       => $request->end_date ?? null,
                               'status'          => 1
                             ];     

                #update
                $updatepackageModule = $query->update($arrayData); 

                return response()->json([
                                          'responseCode'    =>$this->successStatus, 
                                          'responseMessage' => 'Package assign module Updated Successfully.'
                                        ]);                      

            } catch (Exception $e) {
                return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => 'Something went wrong.'
                                        ]);  
            }
     }


   /**
     * delete packageAssignModule
     * @param $id
     * @return \Illuminate\Http\Response
     */
    public function delete($id)
    {
        $query = $this->packageAssignModule;

        # delete packageAssignModule by id
        $query->where('id', $id)->delete();

        # return success
        return [$this->successKey => $this->successStatus, $this->messageKey => $this->deleteMessage($this->type) ];
    }


   
}
