<?php

namespace App\Http\Controllers\Admin;

use App\Http\Traits\MessageStatusTrait;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\PackageModule;
use App\Models\Module;
use Validator;
use Auth;
use Hash;
use File;

class PackageModuleController extends Controller
{
    use MessageStatusTrait;

    # Bind location
    protected $view = 'admin.package-module.';
    protected $type = 'Package Module ';


    # Bind packageModule
    protected $packageModule;
    protected $module;
  
    /**
     * default constructor
     * @param
     * @return
     */
    function __construct(
                          Module        $module,
                          PackageModule $packageModule
                        )
                        {
                            $this->module          = $module;
                            $this->packageModule   = $packageModule;
                            $this->page = config('paginate.pagination');
                        }



   
    #packageModule page
    public function index(Request $request){
        $query = $this->packageModule;
      
        $packageModule_list = $query->orderBy('id','desc')->paginate($this->page);
        return view($this->view.'index')->with([
                                                 'packageModule_list'  => $packageModule_list ?? [],
                                               ]);
    }



     #packageModule add page
    public function create(Request $request){
          $module_list = $this->module->where('status',1)->get();
          return view($this->view.'add')->with(['module_list' => $module_list]);
    }



    /**
      * add packageModule
      * @param Illuminate\Http\Request; 
      * @return Illuminate\Http\Response;
      */
     public function store(Request $request)
     {
      $data = [
                'name'           => 'required',
                'duration'       => 'required',
                'module_id'      => 'required',
             ];

            # validation check
            $validator = Validator::make($request->all() , $data);
            if($validator->fails())
             {
                return response()->json([
                                          'responseCode'    =>  $this->errorStatus, 
                                          'responseMessage' => 'Required field is missing.'
                                        ]);
             }

            try { 
                
                # request param
                $arrayData = [
                               'name'            => $request->name ?? null,
                               'duration'        => $request->duration ?? null,
                               'module_id'       => $request->module_id ?? null,
                               'status'          => 1
                             ];     

                #store
                $storepackageModule = $this->packageModule->create($arrayData); 

                               
                return response()->json([
                                          'responseCode'    =>$this->successStatus, 
                                          'responseMessage' => 'package module added successfully.'
                                        ]);                      

            } catch (Exception $e) {
                return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => 'Something went wrong.'
                                        ]);  
            }
     }


    /**
     * edit page
     * @param Illuminate\Http\Request;
     * @return Illuminate\Http\Response;
     */
    public function update($id)
    {  
        # Fetch packageModule by id
         $packageModule = $this->packageModule
                           ->where('id', $id)
                           ->first();
        $module_list = $this->module->where('status',1)->get();                   
        # code...
        return view($this->view . 'edit')->with(['packageModule' => $packageModule,'module_list' => $module_list]);
    }



    /**
      * edit packageModule
      * @param Illuminate\Http\Request; 
      * @return Illuminate\Http\Response;
      */
     public function edit(Request $request)
     {
        $data = [
                'name'           => 'required',
                'duration'       => 'required',
                'module_id'      => 'required',
             ];

            # validation check
            $validator = Validator::make($request->all() , $data);
            if($validator->fails())
             {
                return response()->json([
                                          'responseCode'    =>  $this->errorStatus, 
                                          'responseMessage' => 'Required field is missing.'
                                        ]);
             }
             
            try {
              
               $query = $this->packageModule
                             ->where('id', $request->id)
                             ->first();
                              
               # request param
                $arrayData = [
                               'name'          => $request->name ?? null,
                               'duration'      => $request->duration ?? null,
                               'module_id'     => $request->module_id ?? null,
                             ];   

                #update
                $updatepackageModule = $query->update($arrayData); 

                return response()->json([
                                          'responseCode'    =>$this->successStatus, 
                                          'responseMessage' => 'Package module Updated Successfully.'
                                        ]);                      

            } catch (Exception $e) {
                return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => 'Something went wrong.'
                                        ]);  
            }
     }


   /**
     * delete packageModule
     * @param $id
     * @return \Illuminate\Http\Response
     */
    public function delete($id)
    {
        $query = $this->packageModule;

        # delete packageModule by id
        $query->where('id', $id)->delete();

        # return success
        return [$this->successKey => $this->successStatus, $this->messageKey => $this->deleteMessage($this->type) ];
    }


   
}
