<?php

namespace App\Http\Controllers\Admin;

use App\Http\Traits\MessageStatusTrait;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\PaymentModule;
use Validator;
use Auth;
use Hash;
use File;

class PaymentModuleController extends Controller
{
    use MessageStatusTrait;

    # Bind location
    protected $view = 'admin.payment-module.';
    protected $type = 'Payment Module ';


    # Bind paymentModule
    protected $paymentModule;
  
    /**
     * default constructor
     * @param
     * @return
     */
    function __construct(
                          PaymentModule $paymentModule
                        )
                        {
                            $this->paymentModule   = $paymentModule;
                            $this->page = config('paginate.pagination');
                        }



   
    #paymentModule page
    public function index(Request $request){
        $query = $this->paymentModule;
      
        $paymentModule_list = $query->orderBy('id','desc')->paginate($this->page);
        return view($this->view.'index')->with([
                                                 'paymentModule_list'  => $paymentModule_list ?? [],
                                               ]);
    }



     #paymentModule add page
    public function create(Request $request){
          return view($this->view.'add');
    }



    /**
      * add paymentModule
      * @param Illuminate\Http\Request; 
      * @return Illuminate\Http\Response;
      */
     public function store(Request $request)
     {
      $data = [
                'name'           => 'required',
                'commission'     => 'required',
             ];

            # validation check
            $validator = Validator::make($request->all() , $data);
            if($validator->fails())
             {
                return response()->json([
                                          'responseCode'    =>  $this->errorStatus, 
                                          'responseMessage' => 'Required field is missing.'
                                        ]);
             }

            try { 
                
                # request param
                $arrayData = [
                               'name'            => $request->name ?? null,
                               'commission'      => $request->commission ?? null,
                               'status'          => 1
                             ];     

                #store
                $storepaymentModule = $this->paymentModule->create($arrayData); 

                               
                return response()->json([
                                          'responseCode'    =>$this->successStatus, 
                                          'responseMessage' => 'Payment module added successfully.'
                                        ]);                      

            } catch (Exception $e) {
                return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => 'Something went wrong.'
                                        ]);  
            }
     }


    /**
     * edit page
     * @param Illuminate\Http\Request;
     * @return Illuminate\Http\Response;
     */
    public function update($id)
    {  
        # Fetch paymentModule by id
         $paymentModule = $this->paymentModule
                           ->where('id', $id)
                           ->first();
        # code...
        return view($this->view . 'edit')->with(['paymentModule' => $paymentModule]);
    }



    /**
      * edit paymentModule
      * @param Illuminate\Http\Request; 
      * @return Illuminate\Http\Response;
      */
     public function edit(Request $request)
     {
        $data = [
                'name'           => 'required',
                'commission'     => 'required',
             ];

            # validation check
            $validator = Validator::make($request->all() , $data);
            if($validator->fails())
             {
                return response()->json([
                                          'responseCode'    =>  $this->errorStatus, 
                                          'responseMessage' => 'Required field is missing.'
                                        ]);
             }
             
            try {
              
               $query = $this->paymentModule
                             ->where('id', $request->id)
                             ->first();
                              
               # request param
                $arrayData = [
                               'name'            => $request->name ?? null,
                               'commission'      => $request->commission ?? null,
                             ];   

                #update
                $updatepaymentModule = $query->update($arrayData); 

                return response()->json([
                                          'responseCode'    =>$this->successStatus, 
                                          'responseMessage' => 'Payment module Updated Successfully.'
                                        ]);                      

            } catch (Exception $e) {
                return response()->json([
                                          'responseCode'    =>$this->errorStatus, 
                                          'responseMessage' => 'Something went wrong.'
                                        ]);  
            }
     }


   /**
     * delete paymentModule
     * @param $id
     * @return \Illuminate\Http\Response
     */
    public function delete($id)
    {
        $query = $this->paymentModule;

        # delete paymentModule by id
        $query->where('id', $id)->delete();

        # return success
        return [$this->successKey => $this->successStatus, $this->messageKey => $this->deleteMessage($this->type) ];
    }


   
}
